{ config, lib, pkgs, ... }:

let
  # Define the start script
  service = "homeassistant";
  startScript = pkgs.writeScript "start-homeassistant.sh" ''
    #!/run/current-system/sw/bin/bash
    
    SERVICE=${service}

    # Update PATH
    PATH=$PATH:/run/current-system/sw/bin

    # Define version variable
    VERSION="2025.3.4"

    # Define the container ID file path
    CIDFILE="/var/run/$SERVICE/$SERVICE.ctr-id"

    # Create directory if it does not exist
    mkdir -p $(dirname $CIDFILE)

    # Log the PATH
    echo "Starting $SERVICE"

    # Run the podman command
    podman run --rm \
      --cidfile=$CIDFILE \
      --name $SERVICE \
      --log-driver=journald \
      --cgroups=no-conmon \
      --sdnotify=conmon \
      -d \
      --replace \
      -e TZ='America/Denver' \
      -v /config/hass:/config \
      -v /run/dbus:/run/dbus:ro \
      -v /etc/localtime:/etc/localtime:ro \
      --cap-add=NET_RAW \
      --network=podman \
      --device=/dev/zigbee:/dev/zigbee \
      --ip=10.10.9.38 \
      ghcr.io/home-assistant/home-assistant:$VERSION

    # Wait for the container to be running
    echo "Waiting for Home Assistant container to start..."
    until podman inspect --format '{{.State.Status}}' $SERVICE | grep -q "running"; do
      echo "Waiting for container $SERVICE to start..."
      sleep 2
    done

    # Run your command after the container starts
    echo "Home Assistant container started. Running post-start command."


  '';
in
{
  systemd.services.${service} = {
    description = "${service} Podman Container";
    serviceConfig = {
      Type = "notify";
      NotifyAccess="all";
      ExecStart = "${startScript}";
      ExecStop = "${pkgs.podman}/bin/podman stop --ignore -t 10 --cidfile=/var/run/${service}/${service}.ctr-id";
      ExecStopPost="${pkgs.podman}/bin/podman rm -f --ignore -t 10 --cidfile=/var/run/${service}/${service}.ctr-id";
      Restart="on-failure";
      RestartSec=10;
      TimeoutStartSec=300;
      TimeoutStopSec=60;
      RemainAfterExit=true;
      RequiresMountsFor="/var/run/${service}";
      After="network-online.target validate-nfs-mounts.service";
    };

    # Ensure that the service starts after network-related services are ready
    after = [ "network-online.target" "validate-nfs-mounts.service" ];
    requires = [ "network-online.target" "validate-nfs-mounts.service" ];

    # No need to specify startLimitIntervalSec unless you want to limit the start attempts
    startLimitIntervalSec = 0;

    # Default target is a common choice, but you might want to use multi-user.target or another suitable target
    wantedBy = [ "multi-user.target" ];
  };
}

